#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/fs.h>
#include <linux/evl_log.h>
#include <linux/string.h>

/*
 * When this module is installed, it attempts to register a facility whose
 * name is FACNAME.  It then logs an event with the resulting facility code.
 * It logs yet another event when the module is unloaded.
 */

posix_log_facility_t myFacCode = 0;
#ifndef FACNAME
#define FACNAME "test_kfacreg"
#endif
const char *myFacName = FACNAME;

int
init_module(void)
{
	int status;
	status = evl_register_facility(myFacName, &myFacCode);
	if (status == 0) {
		posix_log_printf(myFacCode, 100, LOG_INFO, 0,
"Registration of facility \"%s\" succeeded.  Facility code = %#x.",
			myFacName, myFacCode);
	} else {
		myFacCode = 0;  /* LOG_KERN */
		posix_log_printf(myFacCode, 101, LOG_ERR, 0,
"Registration of facility \"%s\" failed with status = %d.",
			myFacName, status);
	}
	return 0;
}

void
cleanup_module(void)
{
	posix_log_printf(myFacCode, 102, LOG_INFO, 0,
		"cleanup_module() for facility \"%s\" called.", myFacName);
}
