#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/fs.h>
#include <linux/evl_log.h>
#include <linux/string.h>

/*
 * When this module is installed, it attempts to register facilities with
 * the 7 indicated names.  (This is intended to simulate the burst of
 * registration requests that might occur at boot time as multiple modules
 * are installed.)  An event is logged for each facility registered.
 */

const char *myFacNames[] = {
	"bashful", "doc", "dopey", "grumpy", "happy", "sleepy", "sneezy", 0
};

int
init_module(void)
{
	posix_log_facility_t myFacCode = 0;
	const char **dwarf;
	char name[100];

	for (dwarf = myFacNames; *dwarf; dwarf++) {
		/*
		 * Prepend "test_" to each name so they'll stand out in the
		 * registry.
		 */
		(void) strcpy(name, "test_");
		(void) strcat(name, *dwarf);
		if (evl_register_facility(name, &myFacCode) == 0) {
			posix_log_printf(myFacCode, 100, LOG_INFO, 0,
"Registration of facility \"%s\" succeeded.  Facility code = %#x.",
				name, myFacCode);
		}
	}
	return 0;
}

void
cleanup_module(void)
{
}
